from metamaska.payload_classifier import PayloadClassifier


class Metamaska:
    def __init__(self):
        self.payload_cls = PayloadClassifier()

    def form(self, meta, probability=False):
        if not meta:
            raise ValueError("meta is required.")

        if probability:
            y_pred_prob = self.payload_cls.predict_proba(meta)
            index = y_pred_prob.argmax(1).item()
            return (self.payload_cls.classes_[index], y_pred_prob[0, index])
        return self.payload_cls.predict(meta)[0]



from urllib.parse import unquote_plus


def unquote(payload):
    unquoted_payload = unquote_plus(payload)
    return payload if unquoted_payload == payload else unquoted_payload


def remove_new_line(payload):
    return ' '.join(payload.strip().splitlines())


def remove_whitespace(payload):
    return ' '.join(payload.split())



import click

from metamaska.metamaska import Metamaska


@click.command(no_args_is_help=True)
@click.option('-m', '--meta', required=True, help = "meta to find form for")
@click.option('-p', '--proba', default=False, help = "To compute probability of given meta")
def main(meta, proba):
    if not meta:
        raise ValueError("meta is required.")

    print(Metamaska().form(meta, proba))


if __name__ == "__main__":
    main()  # pragma: no cover



import os

import joblib
from huggingface_hub import hf_hub_download

from metamaska.utils import remove_new_line, remove_whitespace, unquote

DEFAULT_LOCATION = os.path.join(os.path.dirname(__file__), 'models', 'payload_clf.joblib')
HF_REPO_ID = "happyhackingspace/metamaska"
HF_FILENAME = "models/payload_clf.joblib"


def _ensure_model(path):
    if not path:
        raise ValueError("payload clf model file doesn't exist")
    if os.path.isfile(path):
        return path
    os.makedirs(os.path.dirname(path), exist_ok=True)
    return hf_hub_download(repo_id=HF_REPO_ID, filename=HF_FILENAME, local_dir=os.path.dirname(os.path.dirname(path)))


class PayloadClassifier:
    def __init__(self, payload_clf_filename=DEFAULT_LOCATION):
        model_path = _ensure_model(payload_clf_filename)
        self.payload_clf = joblib.load(model_path)
        self.classes_ = self.payload_clf.classes_

    def _transform(self, payload):
        if not payload:
            raise ValueError("payload is required.")

        payload = unquote(payload)
        payload = remove_new_line(payload)
        payload = payload.lower()
        payload = remove_whitespace(payload)

        return payload

    def predict(self, payload):
        payload = self._transform(payload)
        return self.payload_clf.predict([payload])

    def predict_proba(self, payload):
        payload = self._transform(payload)
        return self.payload_clf.predict_proba([payload])
